/**
 * apeman app to handle request/response headers.
 * @memberof module:apeman-app-header/lib
 * @function apemanAppHeader
 * @param {object} [options] - Optional settings.
 * @param {string} [options.nameForReq='header'] - Property name for req header function.
 * @param {string} [options.nameForRes='header'] - Property name for res header function.
 * @returns {function} - Defined app function.
 */

'use strict'

/** @lends create */
function create (options = {}) {
  let nameForReq = options.nameForReq || 'header'
  let nameForRes = options.nameForRes || 'header'

  function reqHeader (name) {
    const req = this
    let { headers } = req
    name = String(name).trim().toLowerCase()
    for (let key of Object.keys(headers)) {
      let hit = key.toLowerCase() === name
      if (hit) {
        return headers[ key ]
      }
    }
    return null
  }

  function resHeader (name, value) {
    var res = this
    switch (arguments.length) {
      case 1:
        return res.getHeader(name)
      case 2:
        res.setHeader(name, value)
        break
      default:
        throw new Error('Invalid number of arguments.')
    }
  }

  /**
   * Defined app.
   * @function app
   * @param {object} req - Request object.
   * @param {object} res - Response object.
   * @param {function} next - Pass to next handler.
   */
  function app (req, res, next) {
    req[ nameForReq ] = req[ nameForReq ] || reqHeader
    res[ nameForRes ] = res[ nameForRes ] || resHeader
    next()
  }

  Object.assign(app, {
    // Description of this app.
    $desc: 'Add header functions to req/res.'
  })

  return app
}

module.exports = create
