/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const co = require('co')
const assert = require('assert')
const apemanport = require('apemanport')
const apemanApp = require('apeman-app')
const apemanrequest = require('apemanrequest')

describe('create', () => {
  let server, baseUrl
  let request = apemanrequest.create({})
  before(() => co(function * () {
    let port = yield apemanport.find()
    let app = create({})
    assert.ok(app)
    server = yield apemanApp('testing-app', {
      port,
      configuration: {
        $apps: {
          'testing-app': {
            '/': [
              app,
              (req, res, next) => {
                var contentType = req.header('Content-Type')
                assert.equal(contentType, 'application/json')
                res.header('foo', 'bar')
                let foo = res.header('foo')
                assert.equal(foo, 'bar')
                res.header('foo', 'baz')
                res.end('Done!')
              }
            ]
          }
        }
      }
    })
    baseUrl = `http://localhost:${port}`
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Create an app.', () => co(function * () {
    let res = yield request({
      url: baseUrl,
      headers: {
        'Content-Type': 'application/json'
      }
    })
    assert.equal(res.headers.foo, 'baz')
  }))
})

/* global describe, before, after, it */
